pub enum Format {
Show 36 variants
Las,
Laz,
Copc,
E57,
Ply,
Pcd,
Xyz,
Txt,
Csv,
Pts,
Ptx,
Rcp,
Rcs,
Potree,
Ept,
GeoTiff,
Cog,
AsciiGrid,
NetCdf,
Hdf5,
Shapefile,
GeoJson,
Gpkg,
Obj,
Fbx,
Gltf,
Glb,
Stl,
Dxf,
Dwg,
Pcap,
UdpPackets,
VendorRaw,
RosBag,
Ros2Bag,
PointCloud2,
}Expand description
Formats from the supplied LiDAR / point-cloud list.
Variants
Las
Laz
Copc
E57
Ply
Pcd
Xyz
Txt
Csv
Pts
Ptx
Rcp
Rcs
Potree
Ept
GeoTiff
Cog
AsciiGrid
NetCdf
Hdf5
Shapefile
GeoJson
Gpkg
Obj
Fbx
Gltf
Glb
Stl
Dxf
Dwg
Pcap
UdpPackets
VendorRaw
RosBag
Ros2Bag
PointCloud2
Implementations
Sourceimpl Format
impl Format
Sourcepub fn from_path(path: impl AsRef<Path>) -> Result<Self>
pub fn from_path(path: impl AsRef<Path>) -> Result<Self>
Infers a format from a path’s extension and known compound extensions.
Sourcepub fn from_path_opt(path: impl AsRef<Path>) -> Option<Self>
pub fn from_path_opt(path: impl AsRef<Path>) -> Option<Self>
Same as Format::from_path, but returns None instead of an error.
Sourcepub const fn family(self) -> FormatFamily
pub const fn family(self) -> FormatFamily
Format family.
Sourcepub const fn support(self) -> FormatSupport
pub const fn support(self) -> FormatSupport
Native support level in this crate.
Sourcepub const fn is_native_read(self) -> bool
pub const fn is_native_read(self) -> bool
Returns true when the format can be read by the built-in codecs.
Sourcepub const fn is_native_write(self) -> bool
pub const fn is_native_write(self) -> bool
Returns true when the format can be written by the built-in codecs.
Sourcepub const fn adapter_hint(self) -> &'static str
pub const fn adapter_hint(self) -> &'static str
Human-readable reason when this format needs an adapter.